#include "libsw_api_perm.h"
#include "libsw_types.h"

/**
 * \brief Check permission for operation with object
 * \param lsw      - libsw handle
 * \param obj      - object to check (may be NULL)
 * \param hidden   - operation to check
 * \return 0 if access permited, nonzero otherwise
*/
int libsw_check_perm(libsw_t *lsw, const libsw_obj_t *obj, libsw_operation_t opr)
{
  uint32_t oflags;
  if (obj) {
    if (lsw->hw->get_obj_flags(LIBSW_HW_HANDLE(lsw), obj, &oflags))
      return LIBSW_NOT_ALLOWED;
    if ((oflags & LIBSW_OBJFLAG_LOCKED) && (opr != LIBSW_OPR_LOCK))
      return LIBSW_NOT_ALLOWED;
  }
  return 0;
}

/**
 * \brief Lock/unlock object for any changes with it
 * \param lsw     - libsw handle
 * \param obj     - object to lock
 * \param lock    - 0/1 clear/set
 * \return 0 if success, nonzero otherwise
*/
int libsw_set_obj_lock(libsw_t *lsw, libsw_obj_t *obj, uint8_t lock)
{
  CHECK_OBJ_PERM(obj, LIBSW_OPR_LOCK);

  return lsw->hw->set_obj_flags(LIBSW_HW_HANDLE(lsw), obj,
                                (lock)?LIBSW_OBJFLAG_LOCKED:0,
                                LIBSW_OBJFLAG_LOCKED);
}

